@@ -25,7 +25,26 @@ export function initDepositAdmin() {
       })
       .DataTable({
         serverSide: true,
-        ajax: Urls.admin_deposit_list(),
+        processing: true,
+        // let's define the order of table options display
+        // f: (f)ilter
+        // l: (l)ength changing
+        // r: p(r)ocessing
+        // t: (t)able
+        // i: (i)nfo
+        // p: (p)agination
+        // see https://datatables.net/examples/basic_init/dom.html
+        dom: '<<"d-flex justify-content-between align-items-center"f' +
+             '<"#list-exclude">l>rt<"bottom"ip>>',
+        // div#list-exclude is a custom filter added next to dataTable
+        // initialization below through js dom manipulation, see
+        // https://datatables.net/examples/advanced_init/dom_toolbar.html
+        ajax: {
+          url: Urls.admin_deposit_list(),
+          data: d => {
+            d.excludePattern = $('#swh-admin-deposit-list-exclude-filter').val();
+          }
+        },
         columns: [
           {
             data: 'id',
@@ -106,6 +125,26 @@ export function initDepositAdmin() {
         scrollCollapse: true,
         order: [[0, 'desc']]
       });
+
+    // Some more customization is needed on the table
+    $('div#list-exclude').html(`<div id="swh-admin-deposit-list-exclude-wrapper">
+    <div id="swh-admin-deposit-list-exclude-div-wrapper" class="dataTables_filter">
+      <label>
+        Exclude:<input id="swh-admin-deposit-list-exclude-filter"
+                       type="search"
+                       value="check-deposit"
+                       class="form-control form-control-sm"
+                       placeholder="exclude-pattern" aria-controls="swh-admin-deposit-list">
+          </input>
+      </label>
+    </div>
+  </div>
+`);
+    // Adding exclusion pattern update behavior, when typing, update search
+    $('#swh-admin-deposit-list-exclude-filter').keyup(function() {
+      depositsTable.draw();
+    });
+    // at last draw the table
     depositsTable.draw();
   });
 
