@@ -899,25 +899,39 @@ def lookup_origin_visits(
     """
     visits = _lookup_origin_visits(origin, last_visit=last_visit, limit=per_page)
     for visit in visits:
-        yield converters.from_origin_visit(visit)
+        visit_status = storage.origin_visit_status_get_latest(origin, visit["visit"])
+        yield converters.from_origin_visit({**visit, **visit_status.to_dict()})
 
 
 def lookup_origin_visit_latest(
-    origin_url: str, require_snapshot: bool
+    origin_url: str,
+    require_snapshot: bool = False,
+    type: Optional[str] = None,
+    allowed_statuses: Optional[Iterable[str]] = None,
 ) -> Optional[OriginVisitInfo]:
     """Return the origin's latest visit
 
     Args:
-        origin_url (str): origin to list visits for
-        require_snapshot (bool): filter out origins without a snapshot
+        origin_url: origin to list visits for
+        type: Optional visit type to filter on (e.g git, tar, dsc, svn,
+            hg, npm, pypi, ...)
+        allowed_statuses: list of visit statuses considered
+            to find the latest visit. For instance,
+            ``allowed_statuses=['full']`` will only consider visits that
+            have successfully run to completion.
+        require_snapshot: filter out origins without a snapshot
 
     Returns:
-       The origin_visit as dict if found
+       The origin visit info as dict if found
 
     """
 
     visit_and_status = origin_get_latest_visit_status(
-        storage, origin_url, require_snapshot=require_snapshot
+        storage,
+        origin_url,
+        type=type,
+        allowed_statuses=allowed_statuses,
+        require_snapshot=require_snapshot,
     )
     return (
         converters.from_origin_visit(
@@ -940,12 +954,13 @@ def lookup_origin_visit(origin_url: str, visit_id: int) -> OriginVisitInfo:
 
     """
     visit = storage.origin_visit_get_by(origin_url, visit_id)
+    visit_status = storage.origin_visit_status_get_latest(origin_url, visit_id)
     if not visit:
         raise NotFoundExc(
             "Origin %s or its visit " "with id %s not found!" % (origin_url, visit_id)
         )
     visit["origin"] = origin_url
-    return converters.from_origin_visit(visit)
+    return converters.from_origin_visit({**visit, **visit_status.to_dict()})
 
 
 def lookup_snapshot_sizes(snapshot_id):
@@ -970,16 +985,23 @@ def lookup_snapshot_sizes(snapshot_id):
             snapshot_id, branches_count=snapshot_sizes["alias"], target_types=["alias"]
         )
         for alias in aliases["branches"].values():
-            if lookup_snapshot(
-                snapshot_id,
-                branches_from=alias["target"],
-                branches_count=1,
-                target_types=["revision"],
-            ):
-                snapshot_sizes["revision"] += 1
-            else:
-                snapshot_sizes["release"] += 1
+            try:
+                for target_type in ("revision", "release"):
+                    snapshot = lookup_snapshot(
+                        snapshot_id,
+                        branches_from=alias["target"],
+                        branches_count=1,
+                        target_types=[target_type],
+                    )
+                    if snapshot and alias["target"] in snapshot["branches"]:
+                        snapshot_sizes[target_type] += 1
+            except NotFoundExc:
+                # aliased revision or release is missing in the snapshot
+                pass
         del snapshot_sizes["alias"]
+        # remove possible None key returned by snapshot_count_branches
+        # when null branches are present in the snapshot
+        snapshot_sizes.pop(None, None)
     return snapshot_sizes
 
 
