@@ -32,7 +32,7 @@ def _authenticate_user(request_factory):
     )
 
 
-def _check_authenticated_user(user, decoded_token):
+def _check_authenticated_user(user, decoded_token, kc_oidc_mock):
     assert user is not None
     assert isinstance(user, OIDCUser)
     assert user.id != 0
@@ -43,16 +43,23 @@ def _check_authenticated_user(user, decoded_token):
     assert user.email == decoded_token["email"]
     assert user.is_staff == ("/staff" in decoded_token["groups"])
     assert user.sub == decoded_token["sub"]
+    resource_access = decoded_token.get("resource_access", {})
+    resource_access_client = resource_access.get(kc_oidc_mock, {})
+    assert user.permissions == set(resource_access_client.get("roles", []))
 
 
 @pytest.mark.django_db
 def test_oidc_code_pkce_auth_backend_success(mocker, request_factory):
-    kc_oidc_mock = mock_keycloak(mocker)
+    """
+    Checks successful login based on OpenID Connect with PKCE extension
+    Django authentication backend (login from Web UI).
+    """
+    kc_oidc_mock = mock_keycloak(mocker, user_groups=["/staff"])
     oidc_profile = sample_data.oidc_profile
     user = _authenticate_user(request_factory)
 
     decoded_token = kc_oidc_mock.decode_token(user.access_token)
-    _check_authenticated_user(user, decoded_token)
+    _check_authenticated_user(user, decoded_token, kc_oidc_mock)
 
     auth_datetime = datetime.fromtimestamp(decoded_token["auth_time"])
     exp_datetime = datetime.fromtimestamp(decoded_token["exp"])
@@ -76,6 +83,10 @@ def test_oidc_code_pkce_auth_backend_success(mocker, request_factory):
 
 @pytest.mark.django_db
 def test_oidc_code_pkce_auth_backend_failure(mocker, request_factory):
+    """
+    Checks failed login based on OpenID Connect with PKCE extension Django
+    authentication backend (login from Web UI).
+    """
     mock_keycloak(mocker, auth_success=False)
 
     user = _authenticate_user(request_factory)
@@ -83,8 +94,28 @@ def test_oidc_code_pkce_auth_backend_failure(mocker, request_factory):
     assert user is None
 
 
+@pytest.mark.django_db
+def test_oidc_code_pkce_auth_backend_permissions(mocker, request_factory):
+    """
+    Checks that a permission defined with OpenID Connect is correctly mapped
+    to a Django one when logging from Web UI.
+    """
+    permission = "webapp.some-permission"
+    mock_keycloak(mocker, user_permissions=[permission])
+    user = _authenticate_user(request_factory)
+    assert user.has_perm(permission)
+    assert user.get_all_permissions() == {permission}
+    assert user.get_group_permissions() == {permission}
+    assert user.has_module_perms("webapp")
+    assert not user.has_module_perms("foo")
+
+
 @pytest.mark.django_db
 def test_drf_oidc_bearer_token_auth_backend_success(mocker, api_request_factory):
+    """
+    Checks successful login based on OpenID Connect bearer token Django REST
+    Framework authentication backend (Web API login).
+    """
     url = reverse("api-1-stat-counters")
     drf_auth_backend = OIDCBearerTokenAuthentication()
 
@@ -96,14 +127,17 @@ def test_drf_oidc_bearer_token_auth_backend_success(mocker, api_request_factory)
     request = api_request_factory.get(url, HTTP_AUTHORIZATION=f"Bearer {access_token}")
 
     user, _ = drf_auth_backend.authenticate(request)
-    _check_authenticated_user(user, decoded_token)
+    _check_authenticated_user(user, decoded_token, kc_oidc_mock)
     # oidc_profile is not filled when authenticating through bearer token
     assert hasattr(user, "access_token") and user.access_token is None
 
 
 @pytest.mark.django_db
 def test_drf_oidc_bearer_token_auth_backend_failure(mocker, api_request_factory):
-
+    """
+    Checks failed login based on OpenID Connect bearer token Django REST
+    Framework authentication backend (Web API login).
+    """
     url = reverse("api-1-stat-counters")
     drf_auth_backend = OIDCBearerTokenAuthentication()
 
@@ -129,7 +163,11 @@ def test_drf_oidc_bearer_token_auth_backend_failure(mocker, api_request_factory)
 
 
 def test_drf_oidc_auth_invalid_or_missing_auth_type(api_request_factory):
-
+    """
+    Checks failed login based on OpenID Connect bearer token Django REST
+    Framework authentication backend (Web API login) due to invalid
+    authorization header value.
+    """
     url = reverse("api-1-stat-counters")
     drf_auth_backend = OIDCBearerTokenAuthentication()
 
@@ -146,3 +184,25 @@ def test_drf_oidc_auth_invalid_or_missing_auth_type(api_request_factory):
 
     with pytest.raises(AuthenticationFailed):
         drf_auth_backend.authenticate(request)
+
+
+@pytest.mark.django_db
+def test_drf_oidc_bearer_token_auth_backend_permissions(mocker, api_request_factory):
+    """
+    Checks that a permission defined with OpenID Connect is correctly mapped
+    to a Django one when using bearer token authentication.
+    """
+    permission = "webapp.some-permission"
+    mock_keycloak(mocker, user_permissions=[permission])
+
+    drf_auth_backend = OIDCBearerTokenAuthentication()
+    access_token = sample_data.oidc_profile["access_token"]
+    url = reverse("api-1-stat-counters")
+    request = api_request_factory.get(url, HTTP_AUTHORIZATION=f"Bearer {access_token}")
+    user, _ = drf_auth_backend.authenticate(request)
+
+    assert user.has_perm(permission)
+    assert user.get_all_permissions() == {permission}
+    assert user.get_group_permissions() == {permission}
+    assert user.has_module_perms("webapp")
+    assert not user.has_module_perms("foo")
