@@ -497,7 +497,7 @@ def test_origin_snapshot_null_branch(
     client, archive_data, new_origin, new_snapshot, visit_dates, revisions
 ):
     snp_dict = new_snapshot.to_dict()
-    new_origin = archive_data.origin_add([new_origin])[0]
+    archive_data.origin_add([new_origin])
     for i, branch in enumerate(snp_dict["branches"].keys()):
         if i == 0:
             snp_dict["branches"][branch] = None
@@ -509,18 +509,10 @@ def test_origin_snapshot_null_branch(
 
     archive_data.snapshot_add([Snapshot.from_dict(snp_dict)])
     visit = archive_data.origin_visit_add(
-        [
-            OriginVisit(
-                origin=new_origin["url"],
-                date=visit_dates[0],
-                type="git",
-                status="ongoing",
-                snapshot=None,
-            )
-        ]
+        [OriginVisit(origin=new_origin.url, date=visit_dates[0], type="git",)]
     )[0]
     visit_status = OriginVisitStatus(
-        origin=new_origin["url"],
+        origin=new_origin.url,
         visit=visit.visit,
         date=now(),
         status="partial",
@@ -529,7 +521,7 @@ def test_origin_snapshot_null_branch(
     archive_data.origin_visit_status_add([visit_status])
 
     url = reverse(
-        "browse-origin-directory", query_params={"origin_url": new_origin["url"]}
+        "browse-origin-directory", query_params={"origin_url": new_origin.url}
     )
     rv = client.get(url)
     assert rv.status_code == 200
@@ -545,7 +537,7 @@ def test_origin_snapshot_invalid_branch(
     client, archive_data, new_origin, new_snapshot, visit_dates, revisions
 ):
     snp_dict = new_snapshot.to_dict()
-    new_origin = archive_data.origin_add([new_origin])[0]
+    archive_data.origin_add([new_origin])
     for i, branch in enumerate(snp_dict["branches"].keys()):
         snp_dict["branches"][branch] = {
             "target_type": "revision",
@@ -554,18 +546,10 @@ def test_origin_snapshot_invalid_branch(
 
     archive_data.snapshot_add([Snapshot.from_dict(snp_dict)])
     visit = archive_data.origin_visit_add(
-        [
-            OriginVisit(
-                origin=new_origin["url"],
-                date=visit_dates[0],
-                type="git",
-                status="ongoing",
-                snapshot=None,
-            )
-        ]
+        [OriginVisit(origin=new_origin.url, date=visit_dates[0], type="git",)]
     )[0]
     visit_status = OriginVisitStatus(
-        origin=new_origin["url"],
+        origin=new_origin.url,
         visit=visit.visit,
         date=now(),
         status="full",
@@ -575,7 +559,7 @@ def test_origin_snapshot_invalid_branch(
 
     url = reverse(
         "browse-origin-directory",
-        query_params={"origin_url": new_origin["url"], "branch": "invalid_branch"},
+        query_params={"origin_url": new_origin.url, "branch": "invalid_branch"},
     )
     rv = client.get(url)
     assert rv.status_code == 404
@@ -748,6 +732,41 @@ def test_origin_empty_snapshot(client, mocker, origin):
     assert mock_service.lookup_snapshot_sizes.called
 
 
+@given(new_origin())
+def test_origin_empty_snapshot_null_revision(client, archive_data, new_origin):
+    snapshot = Snapshot(
+        branches={
+            b"HEAD": SnapshotBranch(
+                target="refs/head/master".encode(), target_type=TargetType.ALIAS,
+            ),
+            b"refs/head/master": None,
+        }
+    )
+    archive_data.origin_add([new_origin])
+    archive_data.snapshot_add([snapshot])
+    visit = archive_data.origin_visit_add(
+        [OriginVisit(origin=new_origin.url, date=now(), type="git",)]
+    )[0]
+    visit_status = OriginVisitStatus(
+        origin=new_origin.url,
+        visit=visit.visit,
+        date=now(),
+        status="partial",
+        snapshot=snapshot.id,
+    )
+    archive_data.origin_visit_status_add([visit_status])
+
+    url = reverse(
+        "browse-origin-directory", query_params={"origin_url": new_origin.url},
+    )
+    resp = client.get(url)
+    assert resp.status_code == 200
+    assert_template_used(resp, "browse/directory.html")
+    resp_content = resp.content.decode("utf-8")
+    assert re.search("snapshot.*is empty", resp_content)
+    assert not re.search("swh-tr-link", resp_content)
+
+
 @given(origin_with_releases())
 def test_origin_release_browse(client, archive_data, origin):
     snapshot = archive_data.snapshot_get_latest(origin["url"])
@@ -809,21 +828,13 @@ def test_origin_browse_directory_branch_with_non_resolvable_revision(
             )
         }
     )
-    new_origin = archive_data.origin_add([new_origin])[0]
+    archive_data.origin_add([new_origin])
     archive_data.snapshot_add([snapshot])
     visit = archive_data.origin_visit_add(
-        [
-            OriginVisit(
-                origin=new_origin["url"],
-                date=now(),
-                type="git",
-                status="ongoing",
-                snapshot=None,
-            )
-        ]
+        [OriginVisit(origin=new_origin.url, date=now(), type="git",)]
     )[0]
     visit_status = OriginVisitStatus(
-        origin=new_origin["url"],
+        origin=new_origin.url,
         visit=visit.visit,
         date=now(),
         status="partial",
@@ -833,7 +844,7 @@ def test_origin_browse_directory_branch_with_non_resolvable_revision(
 
     url = reverse(
         "browse-origin-directory",
-        query_params={"origin_url": new_origin["url"], "branch": branch_name},
+        query_params={"origin_url": new_origin.url, "branch": branch_name},
     )
 
     resp = client.get(url)
@@ -1276,21 +1287,13 @@ def test_origin_branches_pagination_with_alias(
         "target_type": "release",
         "target": hash_to_bytes(existing_release),
     }
-    new_origin = archive_data.origin_add([new_origin])[0]
+    archive_data.origin_add([new_origin])
     archive_data.snapshot_add([Snapshot.from_dict(snp_dict)])
     visit = archive_data.origin_visit_add(
-        [
-            OriginVisit(
-                origin=new_origin["url"],
-                date=visit_dates[0],
-                type="git",
-                status="ongoing",
-                snapshot=None,
-            )
-        ]
+        [OriginVisit(origin=new_origin.url, date=visit_dates[0], type="git",)]
     )[0]
     visit_status = OriginVisitStatus(
-        origin=new_origin["url"],
+        origin=new_origin.url,
         visit=visit.visit,
         date=now(),
         status="full",
@@ -1298,9 +1301,7 @@ def test_origin_branches_pagination_with_alias(
     )
     archive_data.origin_visit_status_add([visit_status])
 
-    url = reverse(
-        "browse-origin-branches", query_params={"origin_url": new_origin["url"]}
-    )
+    url = reverse("browse-origin-branches", query_params={"origin_url": new_origin.url})
     resp = client.get(url)
     assert resp.status_code == 200
     assert_template_used(resp, "browse/branches.html")
